/* preprint.exe - takes a text file and breaks it into separate pages,
   with headings and page numbers (if there is more than one page),
   then sends it to the printer.

   By C.A.B. 22/1/00
   Modified on 13/4/02, 16/11/02 and 1/12/02 */

#include <conio.h>
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <process.h>
#include <dos.h>
#include <ctype.h>
#include <time.h>

#define CR 10
void getstring(char thestring[13],char prompt[], int x, int y);
void getint(int *theint,char prompt[], int x, int y);
int getyn(char prompt[], int x, int y);
int breakupfile(char title[], int printcopyright, char copyrightnotice[], int doublespaced, int keeplines, int indentpar, int html);
int getfirstpage(char title[], int printcopyright, char copyrightnotice[], int doublespaced);
int getnewpage(int pagenum, char title[], int printcopyright, char copyrightnotice[]);
int getline(char aline[201], int *heading);
int getlineskiphtml(char aline[201], int *heading);
int processhtml(char aline[201]);
void substitutehtml(char newline[201], char ignoredword[]);
int getprelim (char title[101], int copyrightexists, char copyrightnotice[101], int html);
void printitsinglesided(int numpages,int numcopies);
void printitdoublesided(int numpages,int numcopies);
void shortencopyright(char thenotice[]);
char * cleanupline(char line[], int html);
void removepagenumber(void);

FILE *fp, *outfp;

void main (int argc, char *argv[])
{
	int copyrightexists;
	int printcopyright = 0;
	int keeplines,indentpar;
	int doublespaced,doublesided,copiestoprint,printnow;
	char filename[80];
	char title[101];
	char copyrightnotice[101] = {""};
	int numpages;
	int a = 10;
	int html = 0;

	textbackground(LIGHTRED);
	textcolor(YELLOW);
	clrscr();
	cputs("Preprint by C.A.B. 22/1/00\n\r");
	cputs("\n\rThis program breaks a text file up into separate pages (single or double\r\n");
	cputs("spaced) and either saves them for you or sends them to the printer.\n\r");
	cputs("It will assume that the first line of text in the file is the title and will\r\n");
	cputs("display this at the top of each page for you, along with the page number.\r\n");
	cputs("If there is a copyright statement or byline following the title you can choose\r\n");
	cputs("whether or not to include it in the output.\r\n");

	if(argc > 1)
		strcpy(filename,argv[1]);
	else
		getstring(filename,"Please enter the file name:  ",1,a++);
	if(access(filename,04))
	{
		cputs("\r\nFile not found - aborting.");
		exit(0);
	}
	if(strlen(filename) >= 5 && stricmp(&(filename[strlen(filename)-4]),".htm") == 0)
	{
		html = 1;
	}
	if(strlen(filename) >= 6 && stricmp(&(filename[strlen(filename)-5]),".html") == 0)
	{
		html = 1;
	}
	copyrightexists = getyn("Is there a copyright notice\\byline in the file (Y/N)?  ",1,a++);
	if(copyrightexists)
		printcopyright = getyn("Should it be printed in the output (Y/N)?  ",1,a++);
	keeplines = getyn("Do you want to keep any existing blank lines between paragraphs (Y/N)?  ",1,a++);
	indentpar = getyn("Do you want to indent the first line of each paragraph (Y/N)?  ",1,a++);
	doublespaced = getyn("Do you want double spacing in the output (Y/N)?  ",1,a++);
	printnow = getyn("Do you want to print it right now? (Y/N)?  ",1,a++);
	if(printnow)
	{
		doublesided = getyn("Do you want to print on both sides of the page? (Y/N)?  ",1,a++);
		getint(&copiestoprint,"Enter the number of copies you want:  ",1,a++);
	}
	cputs("\r\nProcessing... please wait\r\n");
	fp = fopen(filename,"rt");
	if(fp)
	{
		if(getprelim(title,copyrightexists,copyrightnotice,html) == 1)
			numpages = breakupfile(title,printcopyright,copyrightnotice,doublespaced,keeplines,indentpar,html);
		fclose(fp);
		if(numpages == 0)
			cprintf("\r\nError, no pages to print.\r\n");
		if(numpages == 1)
			removepagenumber();
		if(numpages > 0 && printnow)
		{
			if(doublesided == 0)
				printitsinglesided(numpages,copiestoprint);
			else
				printitdoublesided(numpages,copiestoprint);
		}
		if(numpages > 0 && !printnow)
		{
			if(numpages > 1)
				cprintf("\r\nThe results are in page1.txt to page%i.txt.\r\n",numpages);
			else
				cprintf("\r\nThe result is in page1.txt.\r\n");
		}
	}
}


int breakupfile(char title[], int printcopyright, char copyrightnotice[], int doublespaced, int keeplines, int indentpar, int html)
{       // Break up file into separate pages for printing

	int numpages = 1;
	char aline[201];
	int reading;
	char outfile[80];
	int numlines;
	int printedonthispage = 0;
	char temp[13];
	int newpar = 1;
	int heading;

	numlines = getfirstpage(title,printcopyright,copyrightnotice,doublespaced);
	do
	{
		strcpy(aline,"");
		if(html)
			reading = getlineskiphtml(aline,&heading);
		else
			reading = getline(aline,&heading);
		if(reading == -1)  // EOF
			break;
		if(strlen(aline) == 0 && !printedonthispage)  // skip over blank lines at top of page
		{
			newpar = 1;
			continue;
		}
		if(strlen(aline) == 0)
		{
			if(newpar == 0)
			{       // first blank line found indicates end of last paragraph and start of new one
				newpar = 1;
				if(keeplines)
				{
					fprintf(outfp,"\n");
					numlines ++;
				}
			}
			else    // any further blank lines are there to delimit a section and should be kept as is
			{
				if(newpar == 1 && !keeplines)
				{       // replace the line we ignored in the logic just above
					newpar = 2;
					fprintf(outfp,"\n");
					numlines ++;
				}
				fprintf(outfp,"\n");
				numlines ++;
				if(doublespaced)
				{
					fprintf(outfp,"\n");
					numlines ++;
				}
			}
		}
		else
		{
			if(newpar && indentpar && !heading && !(aline[0] == 32 && aline[1] == 32)) // check if the file already has the line indented
				fprintf(outfp,"  ");
			fprintf(outfp,"       %s\n",aline);
			printedonthispage = 1;
			newpar = 0;
			numlines ++;
			if(doublespaced)
			{
				fprintf(outfp,"\n");
				numlines ++;
			}
		}
		if(numlines >= 63)
		{       // time to start a new page
			fclose(outfp);
			numpages++;
			numlines = getnewpage(numpages,title,printcopyright,copyrightnotice);
			printedonthispage = 0;
		}
	} while(reading);
	fclose(outfp);
	if(!printedonthispage)
	{
		sprintf(temp,"page%i.txt",numpages);
		remove(temp);
		numpages --;
	}
	return(numpages);
}


void getstring(char thestring[13],char prompt[], int x, int y)
{
	do
	{
		gotoxy(x,y);
		cputs(prompt);
		strcpy(thestring,"");
		gets(thestring);
	} while(strlen(thestring) == 0);
}


void getint(int *theint,char prompt[], int x, int y)
{
	char thestring[10];

	do
	{
		gotoxy(x,y);
		cputs(prompt);
		strcpy(thestring,"");
		gets(thestring);
	} while(atoi(thestring) == 0);
	*theint = atoi(thestring);
}


int getyn(char prompt[], int x, int y)
{
	char thestring[80];

	do
	{
		gotoxy(x,y);
		cputs(prompt);
		strcpy(thestring,"");
		gets(thestring);
	} while(stricmp(thestring,"y") && stricmp(thestring,"n"));
	return(stricmp(thestring,"y") == 0);
}


int getfirstpage(char title[], int printcopyright, char copyrightnotice[], int doublespaced)
{       // Prints the title, copyright notice if applicable, and page
	// number at the top of a new page.  Returns the number of lines
	// (including blank lines for spacing) that it printed.

	char pagenumline[75];
	char firstline[101];
	int a, b;
	int thelen;
	int linesattop;

	strcpy(pagenumline,"");
	strcpy(firstline,"");

	for(b=1;b<=72;b++)
		strcat(pagenumline," ");
	strcat(pagenumline,"1");
	if(strlen(title) > 60) // too long!
		title[60] = '\0';
	if(printcopyright)
	{
		if(strlen(copyrightnotice) > 65) // too long!
			copyrightnotice[65] = '\0';
	}
	outfp=fopen("page1.txt","wt");
	fprintf(outfp,"\n%s\n",pagenumline);
	fprintf(outfp,"\n\n");
	a = (78 - strlen(title)) / 2;
	for(b=1;b<=a;b++)
		fprintf(outfp," ");
	fprintf(outfp,"%c-1%cE%s%cF%c-0\n\n",27,27,title,27,27);
	linesattop = 6;
	if(printcopyright)
	{
		a = (78 - strlen(copyrightnotice)) / 2;
		for(b=1;b<=a;b++)
			fprintf(outfp," ");
		fprintf(outfp,"%c-1%s%c-0\n\n",27,copyrightnotice,27);  // underlined
		linesattop += 2;
	}
	fprintf(outfp,"\n\n");
	linesattop += 2;
	if(doublespaced)
	{
		fprintf(outfp,"\n\n");
		linesattop += 2;
	}
	return(linesattop);
}


int getnewpage(int pagenum, char title[], int printcopyright, char copyrightnotice[])
{       // Prints the title, copyright notice if applicable, and page
	// number at the top of a new page.  Returns the number of lines
	// (including blank lines for spacing) that it printed.

	char pagenumline[75];
	char pagenumstring[5];
	char outfilename[80];
	char firstline[101];
	int a, b;
	int thelen;
	int linesattop;

	itoa(pagenum,pagenumstring,10);
	strcpy(pagenumline,"");
	strcpy(firstline,"");

	sprintf(firstline,"       %s",title);
	if(printcopyright)
	{
		if(strlen(firstline)+strlen(copyrightnotice) > 65)
			shortencopyright(copyrightnotice);
		if(strlen(firstline)+strlen(copyrightnotice) <= 65)
		{
			strcat(firstline," - ");
			strcat(firstline,copyrightnotice);
		}
	}
	for(b=strlen(firstline);b<=70+(pagenum<10);b++)
		strcat(firstline," ");
	strcat(firstline,pagenumstring);
	sprintf(outfilename,"page%i.txt",pagenum);
	outfp=fopen(outfilename,"wt");
	fprintf(outfp,"\n%s\n\n\n\n\n\n",firstline);
	linesattop = 7;
	return(linesattop);
}


int getline(char aline[201], int *heading)
{
	char *result;
	int a;

	*heading = 0;
	result = fgets(aline,199,fp);
	if(result == NULL)  // EOF
		return - 1;
	aline[strlen(aline)-1] = '\0';
	if(strlen(aline) == 0)
		return 1;
	// Check for a line that has nothing but spaces or nonprintable chars
	// and change it to a blank line, to avoid confusing the program
	a = 0;
	while(aline[a] <= 32 && aline[a] != '\0')
		a ++;
	if(a > 0 && a == strlen(aline))
	{
		strcpy(aline,"");
		return 1;
	}
	// A line that's entirely in capital letters (or to be exact,
	// that has no lowercase letters) is taken to be a heading
	a = 0;
	while((aline[a] < 97 || aline[a] > 122) && aline[a] != '\0')   // 97 is lowercase 'a', 122 is lowercase 'z'
		a++;
	if(a > 0 && a == strlen(aline))
		*heading = 1;
	return 1;
}


int getlineskiphtml(char aline[201], int *heading)
{
	int result = 1;
	int ignoringlinks = 0;
	int a;

	while(1)
	{
		*heading = 0;
		result = getline(aline,heading);
		if(result == -1) // EOF
			break;
		if(strnicmp(aline,"<!-- links",10) == 0 || strnicmp(aline,"<!-- comments",13) == 0)
		{
			ignoringlinks = 1;
			continue;
		}
		if(strnicmp(aline,"<!-- end",8) == 0)
		{
			ignoringlinks = 0;
			continue;
		}
		if(ignoringlinks)  // ignore everything until <!-- end
			continue;
		if(strlen(aline) == 0)
			break;
		if(strnicmp(aline,"<h1>",4) == 0 ||
		   strnicmp(aline,"<h2>",4) == 0 ||
		   strnicmp(aline,"<h3>",4) == 0 ||
		   strnicmp(aline,"<h4>",4) == 0 ||
		   strnicmp(aline,"<h5>",4) == 0 ||
		   strnicmp(aline,"<h6>",4) == 0)
		{
			*heading = 1;
		}
		if(strnicmp(aline,"<p>",3) == 0)
		{       // Check for a line containing nothing but <p> or <p> followed by spaces
			// and change it to a blank line to indicate a new paragraph
			if(strlen(aline) > 3)
			{	// Check if there's anything other than spaces after it
				a = 3;
				while(aline[a] <= 32 && aline[a] != '\0')
					a++;
				if(a == strlen(aline))
				{
					strcpy(aline,"");
					break;
				}
			}
			else
			{
				strcpy(aline,"");
				break;
			}
		}
		if(processhtml(aline) == 0)  // found a line containing nothing but HTML so ignore it
			continue;
		break;
	}
	return result;
}


int processhtml(char aline[201])
{	// Check for some HTML tags and substitute standard printer escape codes
	// Remove all other HTML
	// Return 0 if the line is now empty, 1 otherwise

	char ignoredword[10];
	char newline[201];
	int a = 0, b = 0, c = 0;
	int ignoring = 0, ignoringamp = 0;

	if(strlen(aline) == 0)
		return 0;

	while(b < 200)
	{
		if(aline[a] == '\0')
			break;
		if(aline[a] == '<')
		{
			ignoring = 1;
			strcpy(ignoredword,"");
			c = 0;
		}
		if(aline[a] == '&' && !ignoring)
		{
			ignoringamp = 1;
			// Check for HTML tags for <, > or &
			if(tolower(aline[a+1]) == 'l' && tolower(aline[a+2]) == 't' && aline[a+3] == ';')
				newline[b++] = '<';
			if(tolower(aline[a+1]) == 'g' && tolower(aline[a+2]) == 't' && aline[a+3] == ';')
				newline[b++] = '>';
			if(tolower(aline[a+1]) == 'a' && tolower(aline[a+2]) == 'm' && tolower(aline[a+3] == 'p') && aline[a+4] == ';')
				newline[b++] = '&';
		}
		if(ignoring && c < 8)  // we don't need to check all of the HTML tag, just the start of it
			ignoredword[c++] = aline[a];
		if(!ignoring && !ignoringamp && aline[a] >= 32)
		      newline[b++] = aline[a];
		if(ignoringamp && (aline[a] == ';' || aline[a] == '\0' || aline[a] == 32))
			ignoringamp = 0;
		if(aline[a] == '>' && ignoring)
		{
			ignoredword[c] = '\0';
			newline[b] = '\0';  // so we can strcat it
			substitutehtml(newline,ignoredword);
			b = strlen(newline);
			strcpy(ignoredword,"");
			c = 0;
			ignoring = 0;
		}
		a++;
	}
	newline[b] = '\0';
	strcpy(aline,newline);
	// Check for a line that has nothing but spaces or nonprintable chars
	// and change it to a blank line, to avoid confusing the program
	a = 0;
	while(aline[a] <= 32 && aline[a] != '\0')
		a ++;
	if(a > 0 && a == strlen(aline))
		strcpy(aline,"");
	if(strlen(aline) == 0)
		return 0;
	else
		return 1;
}


void substitutehtml(char newline[201], char ignoredword[])
{	// Check for certain HTML tags and return standard printer
	// escape codes for them

	char codestr[5];

	strcpy(codestr,"");
	if(stricmp(ignoredword,"<i>") == 0)
	{
		codestr[0] = 27;
		codestr[1] = '4';  // italics
		codestr[2] = '\0';
	}
	else if(stricmp(ignoredword,"</i>") == 0)
	{
		codestr[0] = 27;
		codestr[1] = '5';  // end italics
		codestr[2] = '\0';
	}
	else if(strcmp(ignoredword,"<u>") == 0)
	{
		codestr[0] = 27;
		codestr[1] = '-';  // underlining
		codestr[2] = '1';
		codestr[3] = '\0';
	}
	else if(strcmp(ignoredword,"</u>") == 0)
	{
		codestr[0] = 27;
		codestr[1] = '-';  // end underlining
		codestr[2] = '0';
		codestr[3] = '\0';
	}
	else if(strcmp(ignoredword,"<b>") == 0)
	{
		codestr[0] = 27;
		codestr[1] = 'E';  // bold text
		codestr[2] = '\0';
	}
	else if(strcmp(ignoredword,"</b>") == 0)
	{
		codestr[0] = 27;
		codestr[1] = 'F';  // end bold text
		codestr[2] = '\0';
	}
	else if(strcmp(ignoredword,"<sup>") == 0)
	{
		codestr[0] = 27;
		codestr[1] = 'S'; // superscript
		codestr[2] = '0';
		codestr[3] = '\0';
	}
	else if(strcmp(ignoredword,"</sup>") == 0)
	{
		codestr[0] = 27;
		codestr[1] = 'T';  // end superscript
		codestr[2] = '\0';
	}
	else if(strcmp(ignoredword,"<sub>") == 0)
	{
		codestr[0] = 27;
		codestr[1] = 'S'; // subscript
		codestr[2] = '1';
		codestr[3] = '\0';
	}
	else if(strcmp(ignoredword,"</sub>") == 0)
	{
		codestr[0] = 27;
		codestr[1] = 'T';  // end subscript
		codestr[2] = '\0';
	}
	strcat(newline,codestr);
}


int getprelim (char title[101], int copyrightexists, char copyrightnotice[101], int html)
{       // Picks up the first non-blank line of text from the file as the title.
	// If copyrightexists is true, picks up the next non-blank line as
	// the copyright notice or byline.  Removes HTML codes if html = 1.

	char aline[201];

	strcpy(title,"");
	strcpy(copyrightnotice,"");
	do
	{
		strcpy(aline,"");
		if(fgets(aline,199,fp) == NULL)
			return 0;
		if(strlen(aline))
		{
			aline[strlen(aline)-1] = '\0';  // Remove carriage return
			if(strlen(aline) > 100)  // too long!
				aline[100] = '\0';
			strcpy(title,cleanupline(aline,html));
		}
	}while(strlen(title) == 0);
	if(copyrightexists)
	{
		do
		{
			strcpy(aline,"");
			if(fgets(aline,199,fp) == NULL)
				return 0;
			if(strlen(aline))
			{
				aline[strlen(aline)-1] = '\0';  // Remove carriage return
				if(strlen(aline) > 100)  // too long!
					aline[100] = '\0';
				strcpy(copyrightnotice,cleanupline(aline,html));
			}
		}while(strlen(copyrightnotice) == 0);
	}
	return 1;
}


void printitsinglesided(int numpages, int numcopies)
{

	int outerloop, innerloop, numdone = 0, a,b;
	char sysmsg[80];
	time_t starttime;

	clrscr();
	cprintf("Now printing %i copies of %i pages, single sided\r\n",numcopies,numpages);
	for(outerloop = 1; outerloop <= numcopies; outerloop ++)
	{
		cprintf("\r\nCopy number: %i\r\n",outerloop);
		for(innerloop = numpages; innerloop >= 1; innerloop --)
		{
			cprintf("Printing page %i\r\n",innerloop);
			sprintf(sysmsg,"print page%i.txt",innerloop);
			system(sysmsg);
			numdone ++;
			if(numdone == 10 && (innerloop > 1 || outerloop < numcopies))
			{
				cputs("Pausing five minutes so the printer can catch up\r\n");
				numdone = 0;
				time(&starttime);
				do
				{
					if(kbhit())
						getch();  // retrieve and discard keystroke
				} while(time(NULL) - starttime < 300);
				cputs("\r\n");
			}
		}
	}
	cputs("\r\nPress a key when the printer has finished\r\n");
	while(1)
	{
		if(kbhit())
			break;
	}
	getch();  // retrieve and discard keystroke

	for(a = 1; a<= numpages+1; a++)
	{
		sprintf(sysmsg,"del page%i.txt",a);
		system(sysmsg);
	}
}


void printitdoublesided(int numpages, int numcopies)
{       // Print the required number of copies of all the odd numbered pages
	// (eg 1,3,5...) then ask the user to turn the pages over
	// and put them in the printer again, so I can print the required
	// number of even numbered pages on the back

	int outerloop, innerloop, numdone = 0, a;
	char sysmsg[80];
	time_t starttime;

	clrscr();
	cprintf("Now printing %i copies of %i pages, double sided\r\n",numcopies,numpages);

	numdone = 0;
	for(outerloop=1;outerloop<=numpages;outerloop+=2)
	{
		for(innerloop=1;innerloop<=numcopies;innerloop++)
		{
			sprintf(sysmsg,"print page%i.txt",outerloop);
			system(sysmsg);
			numdone ++;
			if(numdone == 10 && (innerloop < numcopies || outerloop < numpages))
			{
				numdone = 0;
				cputs("Pausing five minutes so the printer can catch up\r\n");
				time(&starttime);
				do
				{
					if(kbhit())
						getch();  // retrieve and discard keystroke
				} while(time(NULL) - starttime < 300);
				cputs("\r\n");
			}
		}
	}
  if(numpages > 1)
  {
	cputs("\r\n***  Please turn the sheaf of pages over and put it back in the printer ***\r\n");
	cputs("Press a key when ready\r\n");
	while(1)
	{
		if(kbhit())
			break;
	}
	getch();  // retrieve and discard keystroke

	numdone = 0;
	for(outerloop=2;outerloop<=numpages;outerloop+=2)
	{
		for(innerloop=1;innerloop<=numcopies;innerloop++)
		{
			sprintf(sysmsg,"print page%i.txt",outerloop);
			system(sysmsg);
			numdone ++;
			if(numdone == 10 && (innerloop < numcopies || outerloop < numpages))
			{
				numdone = 0;
				cputs("Pausing five minutes so the printer can catch up\r\n");
				time(&starttime);
				do
				{
					if(kbhit())
						getch();  // retrieve and discard keystroke
				} while(time(NULL) - starttime < 300);
				cputs("\r\n");
			}
		}
	}
  }
  cputs("\r\nPress a key when the printer has finished\r\n");
  while(1)
  {
	if(kbhit())
		break;
  }
  getch();  // retrieve and discard keystroke

  for(a = 1; a<= numpages+1; a++)
  {
	sprintf(sysmsg,"del page%i.txt",a);
	system(sysmsg);
  }
}


void shortencopyright(char thenotice[])
{       // Remove the word 'copyright' and the date

	char newnotice[101];
	int a;

	strcpy(newnotice,"");
	if(strnicmp(thenotice,"copyright",9) == 0)
		strcpy(newnotice,&(thenotice[10]));
	else
		strcpy(newnotice,thenotice);
	if(isdigit(newnotice[strlen(newnotice)-4]))
		newnotice[strlen(newnotice)-4] = '\0';
	strcpy(thenotice,newnotice);
}


char * cleanupline(char aline[], int html)
{       // Takes a line and removes spaces at the beginning.  Removes HTML
	// tags if html = 1

	char newline[101];
	int a = 0, b = 0;
	int ignoring = 0, ignoringamp = 0;

	while(aline[a] == ' ')
		a++;
	if(!html)
	{
		strcpy(newline,&(aline[a]));
		return newline;
	}
	while(b < 100)
	{
		if(aline[a] == '\0')
			break;
		if(aline[a] == '<')
			ignoring = 1;
		if(aline[a] == '&')
		{
			ignoringamp = 1;
			// Check for HTML tags for <, > or &
			if(tolower(aline[a+1]) == 'l' && tolower(aline[a+2]) == 't' && aline[a+3] == ';')
				newline[b++] = '<';
			if(tolower(aline[a+1]) == 'g' && tolower(aline[a+2]) == 't' && aline[a+3] == ';')
				newline[b++] = '>';
			if(tolower(aline[a+1]) == 'a' && tolower(aline[a+2]) == 'm' && tolower(aline[a+3] == 'p') && aline[a+4] == ';')
				newline[b++] = '&';
		}
		if(!ignoring && !ignoringamp && aline[a] >= 32)
		      newline[b++] = aline[a];
		if(ignoringamp && (aline[a] == ';' || aline[a] == '\0' || aline[a] == 32))
			ignoringamp = 0;
		if(aline[a] == '>')
			ignoring = 0;
		a++;
	}
	newline[b] = '\0';
	return newline;
}


void removepagenumber(void)
{       // Removes the page number from the top of the page
	// (used when there is only one page and therefore no need to
	// number it)

	FILE *oldfp, *newfp;
	char line[201];

	rename("page1.txt","page1old.txt");
	oldfp = fopen("page1old.txt","rt");
	newfp = fopen("page1.txt","wt");
	fscanf(oldfp,"%*[^\n]");  // first line is blank
	fgetc(oldfp);
	fscanf(oldfp,"%*[^\n]");  // second line has page number
	fgetc(oldfp);
	fprintf(newfp,"\n\n");
	while(1)
	{
		if(fscanf(oldfp,"%[^\n]",line) == EOF)
			break;
		fgetc(oldfp);
		fprintf(newfp,"%s\n",line);
	}
	fclose(oldfp);
	fclose(newfp);
	remove("page1old.txt");
}
